Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1899)

Unified Diff: chrome/browser/ui/views/tabs/tab_strip.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Fix test Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/tabs/tab_controller.h ('k') | chrome/browser/ui/views/tabs/tab_strip.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/tabs/tab_strip.h
diff --git a/chrome/browser/ui/views/tabs/tab_strip.h b/chrome/browser/ui/views/tabs/tab_strip.h
index 1a29593c5e0f277843a8f0cfc12781827e6076cb..17c8c5c993f8fc1d35b26d8aa4d6d6ef9dbc07d0 100644
--- a/chrome/browser/ui/views/tabs/tab_strip.h
+++ b/chrome/browser/ui/views/tabs/tab_strip.h
@@ -241,7 +241,7 @@ class TabStrip : public views::View,
SkColor GetToolbarTopSeparatorColor() const override;
int GetBackgroundResourceId(bool* custom_image) const override;
void UpdateTabAccessibilityState(const Tab* tab,
- ui::AXViewState* state) override;
+ ui::AXNodeData* node_data) override;
// MouseWatcherListener overrides:
void MouseMovedOutOfHost() override;
@@ -257,7 +257,7 @@ class TabStrip : public views::View,
int OnDragUpdated(const ui::DropTargetEvent& event) override;
void OnDragExited() override;
int OnPerformDrop(const ui::DropTargetEvent& event) override;
- void GetAccessibleState(ui::AXViewState* state) override;
+ void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
views::View* GetTooltipHandlerForPoint(const gfx::Point& point) override;
// Returns preferred height in immersive style.
@@ -379,7 +379,7 @@ class TabStrip : public views::View,
int GetPinnedTabCount() const;
// Returns the last tab in the strip that's actually visible. This will be
// the actual last tab unless the strip is in the overflow state.
const Tab* GetLastVisibleTab() const;
// Adds the tab at |index| to |tabs_closing_map_| and removes the tab from
« no previous file with comments | « chrome/browser/ui/views/tabs/tab_controller.h ('k') | chrome/browser/ui/views/tabs/tab_strip.cc » ('j') | no next file with comments »
@@ -379,7 +379,7 @@ class TabStrip : public views::View,
int GetPinnedTabCount() const;
// Returns the last tab in the strip that's actually visible. This will be
- // the actual last tab unless the strip is in the overflow state.
+ // the actual last tab unless the strip is in the overflow node_data.
const Tab* GetLastVisibleTab() const;
// Adds the tab at |index| to |tabs_closing_map_| and removes the tab from

Powered by Google App Engine
This is Rietveld 408576698